--
-- PostgreSQL database dump
--
-- Database dump for the qmail-msglog program
--
-- Copyright (c) 2004  Peter Pentchev
-- All rights reserved.
--
-- Redistribution and use in source and binary forms, with or without
-- modification, are permitted provided that the following conditions
-- are met:
-- 1. Redistributions of source code must retain the above copyright
--    notice, this list of conditions and the following disclaimer.
-- 2. Redistributions in binary form must reproduce the above copyright
--    notice, this list of conditions and the following disclaimer in the
--    documentation and/or other materials provided with the distribution.
--
-- THIS SOFTWARE IS PROVIDED BY THE AUTHOR AND CONTRIBUTORS ``AS IS'' AND
-- ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE
-- IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE
-- ARE DISCLAIMED.  IN NO EVENT SHALL THE AUTHOR OR CONTRIBUTORS BE LIABLE
-- FOR ANY DIRECT, INDIRECT, INCIDENTAL, SPECIAL, EXEMPLARY, OR CONSEQUENTIAL
-- DAMAGES (INCLUDING, BUT NOT LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS
-- OR SERVICES; LOSS OF USE, DATA, OR PROFITS; OR BUSINESS INTERRUPTION)
-- HOWEVER CAUSED AND ON ANY THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT
-- LIABILITY, OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY
-- OUT OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF
-- SUCH DAMAGE.
--
-- $Ringlet: perl/mail/qmail-msglog/sql/pgsql.sql,v 1.3 2004/10/20 00:15:39 roam Exp $

SET client_encoding = 'SQL_ASCII';
SET check_function_bodies = false;

--
-- TOC entry 5 (OID 1736286)
-- Name: maillog; Type: SCHEMA; Schema: -; Owner: 
--

CREATE SCHEMA maillog;


--
-- TOC entry 4 (OID 2200)
-- Name: public; Type: ACL; Schema: -; Owner: pgsql
--

REVOKE ALL ON SCHEMA public FROM PUBLIC;
GRANT ALL ON SCHEMA public TO PUBLIC;


SET search_path = maillog, pg_catalog;

--
-- TOC entry 6 (OID 1736287)
-- Name: mail_msg_id; Type: SEQUENCE; Schema: maillog; Owner: pgsql
--

CREATE SEQUENCE mail_msg_id
    START WITH 1
    INCREMENT BY 1
    NO MAXVALUE
    NO MINVALUE
    CACHE 1;


--
-- TOC entry 7 (OID 1736289)
-- Name: mail_msg; Type: TABLE; Schema: maillog; Owner: pgsql
--

CREATE TABLE mail_msg (
    id integer DEFAULT (nextval('maillog.mail_msg_id'::text))::integer NOT NULL,
    sender character varying(100) DEFAULT ''::character varying NOT NULL,
    msg_id character varying(80) DEFAULT ''::character varying NOT NULL,
    subject character varying(200) DEFAULT ''::character varying NOT NULL,
    length integer DEFAULT 0 NOT NULL,
    hdrlen integer DEFAULT 0 NOT NULL,
    tstamp timestamp without time zone NOT NULL
);


--
-- TOC entry 8 (OID 1736301)
-- Name: mail_recip; Type: TABLE; Schema: maillog; Owner: pgsql
--

CREATE TABLE mail_recip (
    msg_id integer NOT NULL,
    idx integer DEFAULT 0 NOT NULL,
    recip character varying(100) DEFAULT ''::character varying NOT NULL
);


--
-- TOC entry 9 (OID 1736312)
-- Name: mail_env; Type: TABLE; Schema: maillog; Owner: pgsql
--

CREATE TABLE mail_env (
    msg_id integer NOT NULL,
    idx integer DEFAULT 0 NOT NULL,
    name character varying(100) NOT NULL,
    value character varying(255) NOT NULL
);


--
-- TOC entry 10 (OID 1736299)
-- Name: mail_msg_by_msg_id; Type: INDEX; Schema: maillog; Owner: pgsql
--

CREATE INDEX mail_msg_by_msg_id ON mail_msg USING btree (msg_id);


--
-- TOC entry 11 (OID 1736300)
-- Name: mail_msg_by_sender; Type: INDEX; Schema: maillog; Owner: pgsql
--

CREATE INDEX mail_msg_by_sender ON mail_msg USING btree (sender);


--
-- TOC entry 13 (OID 1736311)
-- Name: mail_recip_by_recip; Type: INDEX; Schema: maillog; Owner: pgsql
--

CREATE INDEX mail_recip_by_recip ON mail_recip USING btree (recip);


--
-- TOC entry 16 (OID 1736321)
-- Name: mail_env_by_name; Type: INDEX; Schema: maillog; Owner: pgsql
--

CREATE INDEX mail_env_by_name ON mail_env USING btree (name);


--
-- TOC entry 15 (OID 1736322)
-- Name: mail_env_by_id_name; Type: INDEX; Schema: maillog; Owner: pgsql
--

CREATE INDEX mail_env_by_id_name ON mail_env USING btree (msg_id, name);


--
-- TOC entry 12 (OID 1736297)
-- Name: mail_msg_pkey; Type: CONSTRAINT; Schema: maillog; Owner: pgsql
--

ALTER TABLE ONLY mail_msg
    ADD CONSTRAINT mail_msg_pkey PRIMARY KEY (id);


--
-- TOC entry 14 (OID 1736305)
-- Name: mail_recip_pkey; Type: CONSTRAINT; Schema: maillog; Owner: pgsql
--

ALTER TABLE ONLY mail_recip
    ADD CONSTRAINT mail_recip_pkey PRIMARY KEY (msg_id, idx);


--
-- TOC entry 17 (OID 1736315)
-- Name: mail_env_pkey; Type: CONSTRAINT; Schema: maillog; Owner: pgsql
--

ALTER TABLE ONLY mail_env
    ADD CONSTRAINT mail_env_pkey PRIMARY KEY (msg_id, idx);


--
-- TOC entry 18 (OID 1736307)
-- Name: $1; Type: FK CONSTRAINT; Schema: maillog; Owner: pgsql
--

ALTER TABLE ONLY mail_recip
    ADD CONSTRAINT "$1" FOREIGN KEY (msg_id) REFERENCES mail_msg(id) ON UPDATE CASCADE ON DELETE CASCADE;


--
-- TOC entry 19 (OID 1736317)
-- Name: $1; Type: FK CONSTRAINT; Schema: maillog; Owner: pgsql
--

ALTER TABLE ONLY mail_env
    ADD CONSTRAINT "$1" FOREIGN KEY (msg_id) REFERENCES mail_msg(id) ON UPDATE CASCADE ON DELETE CASCADE;


--
-- TOC entry 3 (OID 1738421)
-- Name: mail_text; Type: TABLE; Schema: maillog; Owner: pgsql
--

CREATE TABLE mail_text (
    msg_id integer NOT NULL,
    msg_len integer NOT NULL,
    msg_limit integer NOT NULL,
    msg_snipped smallint NOT NULL,
    msg_type character varying(255) NOT NULL,
    msg_text text NOT NULL
);


--
-- TOC entry 4 (OID 1738426)
-- Name: mail_text_pkey; Type: CONSTRAINT; Schema: maillog; Owner: pgsql
--

ALTER TABLE ONLY mail_text
    ADD CONSTRAINT mail_text_pkey PRIMARY KEY (msg_id);


--
-- TOC entry 3 (OID 2200)
-- Name: SCHEMA public; Type: COMMENT; Schema: -; Owner: pgsql
--

COMMENT ON SCHEMA public IS 'Standard public schema';
